#include "vnl/vnl_matrix.hxx"

VNL_MATRIX_INSTANTIATE(unsigned short);
